@@ -193,11 +193,11 @@ impl Backend for GoPlugin {
             Ok(versions)
         })
     }
-    fn legacy_filenames(&self) -> eyre::Result<Vec<String>> {
+    fn idiomatic_filenames(&self) -> eyre::Result<Vec<String>> {
         Ok(vec![".go-version".into()])
     }
 
-    fn install_version_impl(
+    fn install_version_(
         &self,
         ctx: &InstallContext,
         mut tv: ToolVersion,
