@@ -128,11 +128,12 @@ impl Plugin for VfoxPlugin {
             .wrap_err("run with --yes to install plugin automatically"))
     }
 
-    fn ensure_installed(&self, _mpr: &MultiProgressReport, _force: bool) -> Result<()> {
+    fn ensure_installed(&self, mpr: &MultiProgressReport, _force: bool) -> Result<()> {
         if !self.plugin_path.exists() {
             let url = self.get_repo_url()?;
             trace!("Cloning vfox plugin: {url}");
-            self.repo().clone(url.as_str())?;
+            let pr = mpr.add(&format!("clone vfox plugin {}", url));
+            self.repo().clone(url.as_str(), Some(pr.as_ref()))?;
         }
         Ok(())
     }
@@ -154,7 +155,7 @@ impl Plugin for VfoxPlugin {
             );
             return Ok(());
         }
-        pr.set_message("updating git repo".into());
+        pr.set_message("update git repo".into());
         git.update(gitref)?;
         let sha = git.current_sha_short()?;
         let repo_url = self.get_remote_url()?.unwrap_or_default();
@@ -169,13 +170,13 @@ impl Plugin for VfoxPlugin {
         if !self.is_installed() {
             return Ok(());
         }
-        pr.set_message("uninstalling".into());
+        pr.set_message("uninstall".into());
 
         let rmdir = |dir: &Path| {
             if !dir.exists() {
                 return Ok(());
             }
-            pr.set_message(format!("removing {}", display_path(dir)));
+            pr.set_message(format!("remove {}", display_path(dir)));
             remove_all(dir).wrap_err_with(|| {
                 format!(
                     "Failed to remove directory {}",
@@ -206,10 +207,10 @@ Plugins could support local directories in the future but for now a symlink is r
             ))?;
         }
         let git = Git::new(&self.plugin_path);
-        pr.set_message(format!("cloning {repo_url}"));
-        git.clone(&repo_url)?;
+        pr.set_message(format!("clone {repo_url}"));
+        git.clone(&repo_url, Some(pr))?;
         if let Some(ref_) = &repo_ref {
-            pr.set_message(format!("checking out {ref_}"));
+            pr.set_message(format!("git update {ref_}"));
             git.update(Some(ref_.to_string()))?;
         }
 
@@ -226,8 +227,9 @@ fn vfox_to_url(name: &str) -> eyre::Result<Url> {
     let name = name.strip_prefix("vfox:").unwrap_or(name);
     if let Some(rt) = registry::REGISTRY.get(name.trim_start_matches("vfox-")) {
         // bun -> version-fox/vfox-bun
-        let full = rt.backends.iter().find(|f| f.starts_with("vfox:")).unwrap();
-        return vfox_to_url(full.split_once(':').unwrap().1);
+        if let Some(full) = rt.backends.iter().find(|f| f.starts_with("vfox:")) {
+            return vfox_to_url(full.split_once(':').unwrap().1);
+        }
     }
     let res = if let Some(caps) = regex!(r#"^([^/]+)/([^/]+)$"#).captures(name) {
         let user = caps.get(1).unwrap().as_str();
